@@ -1,11 +1,11 @@
-from deeplab import DeepLab
+from .deeplab import DeepLab
 import numpy as np
 import pandas as pd
 import cv2
 import torch
 from torchvision import transforms
-from data import decodePredicts
-from Config import ConfigTrain
+from .data import decodePredicts
+from .Config import ConfigTrain
 
 
 def inference():
