@@ -1,5 +1,5 @@
 import torch
-from loss import *
+from .loss import *
 import numpy as np
 import torch.nn.functional as F
 
